notify_actor_status_changed

Function notify_actor_status_changed 

pub fn notify_actor_status_changed(event: ActorStatusEvent)
Notify the registered dispatcher that an actor changed status. If no dispatcher is registered yet, the event is buffered and will be replayed when set_entity_dispatcher is called.