set_entity_dispatcher

Function set_entity_dispatcher 

pub fn set_entity_dispatcher(dispatcher: Box<dyn EntityEventDispatcher>)
Set the dispatcher to receive all entity events.

Any events that were emitted before this call are replayed to the new dispatcher in order. All subsequent events are dispatched directly.

Note: Only one dispatcher is supported. Setting a new dispatcher replaces any previously set dispatcher.