pub fn notify_actor_created(event: ActorEvent)Expand description
Notify the registered dispatcher that an actor was created.
If no dispatcher is registered yet, the event is buffered and will be
replayed when set_entity_dispatcher is called.
pub fn notify_actor_created(event: ActorEvent)Notify the registered dispatcher that an actor was created.
If no dispatcher is registered yet, the event is buffered and will be
replayed when set_entity_dispatcher is called.