pub fn notify_mesh_created(event: MeshEvent)
Notify the registered dispatcher that a mesh was created. If no dispatcher is registered yet, the event is buffered and will be replayed when set_entity_dispatcher is called.
set_entity_dispatcher