pub fn notify_sent_message(event: SentMessageEvent)Expand description
Notify the registered dispatcher that a message was sent.
If no dispatcher is registered yet, the event is buffered and will be
replayed when set_entity_dispatcher is called.
pub fn notify_sent_message(event: SentMessageEvent)Notify the registered dispatcher that a message was sent.
If no dispatcher is registered yet, the event is buffered and will be
replayed when set_entity_dispatcher is called.